星门引擎是一款开源的(IPA)智能流程自动化开发框架

官方首页:
http://www.pystargate.com/

文档教程：
http://www.pystargate.com/index.php/wendangjiaocheng.html

一、基本简介
支持python2.7或python3.4版本以上，功能丰富
支持桌面电脑、树莓派、STM32等开发平台
支持linux和windows操作系统

二、应用范围
软件自动化(例如抖音极速版赚钱脚本)、工业自动化、物联网、智能机器人、智能监控、智能农业、智能飞行器等领域

三、功能介绍：
1.获取坐标、鼠标点击、鼠标移动、鼠标位移、鼠标滚动
2.热键组合按键、输入字符串和数字
3.文件批量查找、文件打开和批量打开、文件复制和批量复制、文件移动和文件批量移动
4.图片批量压缩、图像截屏、文字截屏、全屏找图、摄像头抓拍、摄像头连续抓拍
5.UI界面(按钮、容器)
6.获取屏幕的宽和高
7.延时、定时终止程序
8.查找字符串、查找中文字符串
9. 【AI功能】图像识别、文字识别、Ocr查字（支持中文、英文、数字）、Ocr抓图识别查字
10.【AI功能】摄像头抓拍识图、摄像头抓拍识字
11.【AI功能】语音合成播放
12.支持星门数据库,可进行中英文字符、图片、音频、视频、附件存储,不占用端口

提示：使用【AI功能】前请先申请账号
申请账号网址：
http://www.pystargate.com/index.php/page/user.html